@@ -8,11 +8,13 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package App::Cme ;
-$App::Cme::VERSION = '1.010';
+$App::Cme::VERSION = '1.016';
 use strict;
 use warnings;
 use 5.10.1;
 
+# See App::Cmd for explanations on this file
+
 use App::Cmd::Setup -app;
 
 1;
@@ -31,7 +33,7 @@ App::Cme - Check or edit configuration data with Config::Model
 
 =head1 VERSION
 
-version 1.010
+version 1.016
 
 =head1 AUTHOR
 
@@ -58,14 +60,6 @@ in addition to those websites please use your favorite search engine to discover
 
 =item *
 
-MetaCPAN
-
-A modern, open-source CPAN search engine, useful to view POD in HTML format.
-
-L<http://metacpan.org/release/App-Cme>
-
-=item *
-
 Search CPAN
 
 The default CPAN search engine, useful to view POD in HTML format.
@@ -74,14 +68,6 @@ L<http://search.cpan.org/dist/App-Cme>
 
 =item *
 
-RT: CPAN's Bug Tracker
-
-The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-Cme>
-
-=item *
-
 AnnoCPAN
 
 The AnnoCPAN is a website that allows community annotations of Perl module documentation.
@@ -98,19 +84,11 @@ L<http://cpanratings.perl.org/d/App-Cme>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/App-Cme>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/App-Cme>
+L<http://cpants.cpanauthors.org/dist/App-Cme>
 
 =item *
 
@@ -140,8 +118,8 @@ L<http://deps.cpantesters.org/?module=App::Cme>
 
 =head2 Bugs / Feature Requests
 
-Please report any bugs or feature requests by email to C<bug-app-cme at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=App-Cme>. You will be automatically notified of any
+Please report any bugs or feature requests by email to C<ddumont at cpan.org>, or through
+the web interface at L<https://github.com/dod38fr/cme-perl/issues>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
