@@ -10,7 +10,7 @@
 # ABSTRACT: Fix the configuration of an application
 
 package App::Cme::Command::fix ;
-$App::Cme::Command::fix::VERSION = '1.010';
+$App::Cme::Command::fix::VERSION = '1.016';
 use strict;
 use warnings;
 use 5.10.1;
@@ -31,6 +31,7 @@ sub opt_spec {
     return ( 
         [ "from=s@"  => "fix only a subset of a configuration tree" ],
         [ "filter=s" => "pattern to select the element name to be fixed"],
+        [ "quiet!"   => "Suppress progress messages" ],
         $class->cme_global_options,
     );
 }
@@ -78,11 +79,11 @@ App::Cme::Command::fix - Fix the configuration of an application
 
 =head1 VERSION
 
-version 1.010
+version 1.016
 
 =head1 SYNOPSIS
 
-  # fix dpkg (requires Config::Model::Dpkg)
+  # fix dpkg (this example requires Config::Model::Dpkg)
   cme fix dpkg
 
 =head1 DESCRIPTION
