@@ -10,7 +10,7 @@
 # ABSTRACT: Edit the configuration of an application with a shell
 
 package App::Cme::Command::shell ;
-$App::Cme::Command::shell::VERSION = '1.010';
+$App::Cme::Command::shell::VERSION = '1.016';
 use strict;
 use warnings;
 use 5.10.1;
@@ -28,6 +28,7 @@ sub opt_spec {
     my ( $class, $app ) = @_;
     return ( 
         [ "open-item=s" => "open a specific item of the configuration" ],
+        [ "quiet!"      => "Suppress progress messages" ],
         $class->cme_global_options,
     );
 }
@@ -48,7 +49,20 @@ sub execute {
 
     my ($model, $inst, $root) = $self->init_cme($opt,$args);
 
-    $self->run_shell_ui($root, $inst->application) ;
+    eval { require Term::ReadLine; };
+    my $has_term_readline = $@ ? 0 : 1;
+
+    $root->deep_check;
+
+    if ($has_term_readline) {
+        require Config::Model::TermUI;
+        $self->run_shell_ui('Config::Model::TermUI', $inst) ;
+    }
+    else {
+        warn "You should install Term::ReadLine for a more friendly user interface\n";
+        require Config::Model::SimpleUI;
+        $self->run_shell_ui('Config::Model::SimpleUI', $inst) ;
+    }
 }
 
 1;
@@ -65,7 +79,7 @@ App::Cme::Command::shell - Edit the configuration of an application with a shell
 
 =head1 VERSION
 
-version 1.010
+version 1.016
 
 =head1 SYNOPSIS
 
